@@ -57,9 +57,7 @@ void GLHardwarePixelBuffer::blitFromMemory(const PixelBox &src, const Box &dstBo
          "GLHardwarePixelBuffer::blitFromMemory");
     PixelBox scaled;
     
-    if(src.getWidth() != dstBox.getWidth() ||
-        src.getHeight() != dstBox.getHeight() ||
-        src.getDepth() != dstBox.getDepth())
+    if(src.getSize() != dstBox.getSize())
     {
         // Scale to destination size.
         // This also does pixel format conversion if needed
@@ -90,12 +88,9 @@ void GLHardwarePixelBuffer::blitToMemory(const Box &srcBox, const PixelBox &dst)
     if(!mBuffer.contains(srcBox))
         OGRE_EXCEPT(Exception::ERR_INVALIDPARAMS, "source box out of range",
          "GLHardwarePixelBuffer::blitToMemory");
-    if(srcBox.left == 0 && srcBox.right == getWidth() &&
-       srcBox.top == 0 && srcBox.bottom == getHeight() &&
-       srcBox.front == 0 && srcBox.back == getDepth() &&
-       dst.getWidth() == getWidth() &&
-       dst.getHeight() == getHeight() &&
-       dst.getDepth() == getDepth() &&
+    if(srcBox.getOrigin() == Vector3i(0, 0 ,0) &&
+       srcBox.getSize() == getSize() &&
+       dst.getSize() == getSize() &&
        GLPixelUtil::getGLInternalFormat(dst.format) != 0)
     {
         // The direct case: the user wants the entire texture in a format supported by GL
@@ -108,9 +103,7 @@ void GLHardwarePixelBuffer::blitToMemory(const Box &srcBox, const PixelBox &dst)
         allocateBuffer();
         // Download entire buffer
         download(mBuffer);
-        if(srcBox.getWidth() != dst.getWidth() ||
-            srcBox.getHeight() != dst.getHeight() ||
-            srcBox.getDepth() != dst.getDepth())
+        if(srcBox.getSize() != dst.getSize())
         {
             // We need scaling
             Image::scale(mBuffer.getSubVolume(srcBox), dst, Image::FILTER_BILINEAR);
@@ -128,7 +121,7 @@ GLTextureBuffer::GLTextureBuffer(GLRenderSystem* renderSystem, GLTexture* parent
                                  GLint level, uint32 width, uint32 height, uint32 depth)
     : GLHardwarePixelBuffer(width, height, depth, parent->getFormat(), (Usage)parent->getUsage()),
       mTarget(parent->getGLTextureTarget()), mFaceTarget(0), mTextureID(parent->getGLID()),
-      mFace(face), mLevel(level), mHwGamma(parent->isHardwareGammaEnabled()), mSliceTRT(0),
+      mLevel(level), mHwGamma(parent->isHardwareGammaEnabled()),
       mRenderSystem(renderSystem)
 {
     // Get face identifier
@@ -139,11 +132,6 @@ GLTextureBuffer::GLTextureBuffer(GLRenderSystem* renderSystem, GLTexture* parent
     // Get format
     mGLInternalFormat = GLPixelUtil::getGLInternalFormat(mFormat, mHwGamma);
     
-    // Default
-    mRowPitch = mWidth;
-    mSlicePitch = mHeight*mWidth;
-    mSizeInBytes = PixelUtil::getMemorySize(mWidth, mHeight, mDepth, mFormat);
-    
     // Log a message
     /*
     std::stringstream str;
@@ -184,15 +172,6 @@ GLTextureBuffer::GLTextureBuffer(GLRenderSystem* renderSystem, GLTexture* parent
 }
 GLTextureBuffer::~GLTextureBuffer()
 {
-    if(mUsage & TU_RENDERTARGET)
-    {
-        // Delete all render targets that are not yet deleted via _clearSliceRTT because the rendertarget
-        // was deleted by the user.
-        for (SliceTRT::const_iterator it = mSliceTRT.begin(); it != mSliceTRT.end(); ++it)
-        {
-            Root::getSingleton().getRenderSystem()->destroyRenderTarget((*it)->getName());
-        }
-    }
 }
 //-----------------------------------------------------------------------------
 void GLTextureBuffer::upload(const PixelBox &data, const Box &dest)
@@ -329,16 +308,13 @@ void GLTextureBuffer::upload(const PixelBox &data, const Box &dest)
 
     // Restore defaults
     glPixelStorei(GL_UNPACK_ROW_LENGTH, 0);
-    if (GLEW_VERSION_1_2)
-        glPixelStorei(GL_UNPACK_IMAGE_HEIGHT, 0);
+    glPixelStorei(GL_UNPACK_IMAGE_HEIGHT, 0);
     glPixelStorei(GL_UNPACK_ALIGNMENT, 4);
 }
 //-----------------------------------------------------------------------------  
 void GLTextureBuffer::download(const PixelBox &data)
 {
-    if(data.getWidth() != getWidth() ||
-        data.getHeight() != getHeight() ||
-        data.getDepth() != getDepth())
+    if(data.getSize() != getSize())
         OGRE_EXCEPT(Exception::ERR_INVALIDPARAMS, "only download of entire buffer is supported by GL",
             "GLTextureBuffer::download");
     mRenderSystem->_getStateCacheManager()->bindGLTexture( mTarget, mTextureID );
@@ -421,8 +397,8 @@ void GLTextureBuffer::blit(const HardwarePixelBufferSharedPtr &src, const Box &s
     /// Destination texture must be 1D, 2D, 3D, or Cube
     /// Source texture must be 1D, 2D or 3D
     
-    // This does not seem to work for RTTs after the first update
-    // I have no idea why! For the moment, disable 
+    // Using this in Terrain composite map RTT interferes with Impostor RTT rendering in pagedgeometry
+    // I have no idea why! For the moment, disable when src is RTT
     if(GLEW_EXT_framebuffer_object && (src->getUsage() & TU_RENDERTARGET) == 0 &&
         (srct->mTarget==GL_TEXTURE_1D||srct->mTarget==GL_TEXTURE_2D
          ||srct->mTarget==GL_TEXTURE_3D)&&mTarget!=GL_TEXTURE_2D_ARRAY_EXT)
@@ -458,11 +434,7 @@ void GLTextureBuffer::blitFromTexture(GLTextureBuffer *src, const Box &srcBox, c
     // Important to disable all other texture units
     RenderSystem* rsys = Root::getSingleton().getRenderSystem();
     rsys->_disableTextureUnitsFrom(0);
-    if (GLEW_VERSION_1_2)
-    {
-        mRenderSystem->_getStateCacheManager()->activateGLTextureUnit(0);
-    }
-
+    mRenderSystem->_getStateCacheManager()->activateGLTextureUnit(0);
 
     /// Disable alpha, depth and scissor testing, disable blending, 
     /// disable culling, disble lighting, disable fog and reset foreground
@@ -490,9 +462,7 @@ void GLTextureBuffer::blitFromTexture(GLTextureBuffer *src, const Box &srcBox, c
     mRenderSystem->_getStateCacheManager()->bindGLTexture(src->mTarget, src->mTextureID);
     
     /// Set filtering modes depending on the dimensions and source
-    if(srcBox.getWidth()==dstBox.getWidth() &&
-        srcBox.getHeight()==dstBox.getHeight() &&
-        srcBox.getDepth()==dstBox.getDepth())
+    if(srcBox.getSize()==dstBox.getSize())
     {
         /// Dimensions match -- use nearest filtering (fastest and pixel correct)
         mRenderSystem->_getStateCacheManager()->setTexParameteri(src->mTarget, GL_TEXTURE_MIN_FILTER, GL_NEAREST);
@@ -546,12 +516,12 @@ void GLTextureBuffer::blitFromTexture(GLTextureBuffer *src, const Box &srcBox, c
         glFramebufferTexture2DEXT(GL_FRAMEBUFFER_EXT, GL_COLOR_ATTACHMENT0_EXT,
             GL_TEXTURE_2D, static_pointer_cast<GLTexture>(tempTex)->getGLID(), 0);
         /// Set viewport to size of destination slice
-        mRenderSystem->_getStateCacheManager()->setViewport(0, 0, dstBox.getWidth(), dstBox.getHeight());
+        mRenderSystem->_getStateCacheManager()->setViewport(Rect(0, 0, dstBox.getWidth(), dstBox.getHeight()));
     }
     else
     {
         /// We are going to bind directly, so set viewport to size and position of destination slice
-        mRenderSystem->_getStateCacheManager()->setViewport(dstBox.left, dstBox.top, dstBox.getWidth(), dstBox.getHeight());
+        mRenderSystem->_getStateCacheManager()->setViewport(Rect(dstBox.left, dstBox.top, dstBox.right, dstBox.bottom));
     }
     
     /// Process each destination slice
@@ -655,8 +625,7 @@ void GLTextureBuffer::blitFromMemory(const PixelBox &src, const Box &dstBox)
     /// - FBO is not supported
     /// - the source dimensions match the destination ones, in which case no scaling is needed
     if (!GLEW_EXT_framebuffer_object ||
-        (src.getWidth() == dstBox.getWidth() && src.getHeight() == dstBox.getHeight() &&
-         src.getDepth() == dstBox.getDepth()))
+        (src.getSize() == dstBox.getSize()))
     {
         GLHardwarePixelBuffer::blitFromMemory(src, dstBox);
         return;
@@ -673,7 +642,7 @@ void GLTextureBuffer::blitFromMemory(const PixelBox &src, const Box &dstBox)
         src.getWidth(), src.getHeight(), src.getDepth(), MIP_UNLIMITED, src.format);
 
     // Upload data to 0,0,0 in temporary texture
-    Box tempTarget(0, 0, 0, src.getWidth(), src.getHeight(), src.getDepth());
+    Box tempTarget(src.getSize());
     tex->getBuffer()->blitFromMemory(src, tempTarget);
 
     // Blit from texture
@@ -693,7 +662,7 @@ RenderTexture *GLTextureBuffer::getRenderTarget(size_t zoffset)
 //********* GLRenderBuffer
 //----------------------------------------------------------------------------- 
 GLRenderBuffer::GLRenderBuffer(GLenum format, uint32 width, uint32 height, GLsizei numSamples):
-    GLHardwarePixelBuffer(width, height, 1, GLPixelUtil::getClosestOGREFormat(format),HBU_WRITE_ONLY),
+    GLHardwarePixelBuffer(width, height, 1, GLPixelUtil::getClosestOGREFormat(format),HBU_GPU_ONLY),
     mRenderbufferID(0)
 {
     mGLInternalFormat = format;
