@@ -59,21 +59,10 @@ namespace {
 namespace Ogre
 {
     //-------------------------------------------------------------------------------------------------//
-    GLXWindow::GLXWindow(GLXGLSupport *glsupport) :
-        mGLSupport(glsupport), mContext(0)
+    GLXWindow::GLXWindow(GLXGLSupport *glsupport) : GLWindow(),
+        mGLSupport(glsupport)
     {
         mWindow = 0;
-
-        mIsTopLevel = false;
-        mIsFullScreen = false;
-        mIsExternal = false;
-        mIsExternalGLControl = false;
-        mClosed = false;
-        mActive = false;
-        mHidden = false;
-        mVisible = false;
-        mVSync = false;
-        mVSyncInterval = 1;
     }
 
     //-------------------------------------------------------------------------------------------------//
@@ -116,7 +105,6 @@ namespace Ogre
         bool gamma = false;
         ::GLXContext glxContext = 0;
         ::GLXDrawable glxDrawable = 0;
-        Window externalWindow = 0;
         Window parentWindow = DefaultRootWindow(xDisplay);
         int left = DisplayWidth(xDisplay, DefaultScreen(xDisplay))/2 - width/2;
         int top  = DisplayHeight(xDisplay, DefaultScreen(xDisplay))/2 - height/2;
@@ -194,13 +182,14 @@ namespace Ogre
 			}
 #endif
 
-            if((opt = miscParams->find("parentWindowHandle")) != end)
+            if ((opt = miscParams->find("parentWindowHandle")) != end ||
+                (opt = miscParams->find("externalWindowHandle")) != end)
             {
                 std::vector<String> tokens = StringUtil::split(opt->second, " :");
 
-                if (tokens.size() == 3)
+                if (tokens.size() >= 3)
                 {
-                    // deprecated display:screen:xid format
+                    // deprecated display:screen:xid:visualinfo format
                     StringConverter::parse(tokens[2], parentWindow);
                 }
                 else
@@ -213,31 +202,6 @@ namespace Ogre
                 // it should be queried from the parentWindow
                 glxDrawable = 0;
             }
-            else if((opt = miscParams->find("externalWindowHandle")) != end)
-            {
-                std::vector<String> tokens = StringUtil::split(opt->second, " :");
-
-                LogManager::getSingleton().logMessage(
-                    "GLXWindow::create: The externalWindowHandle parameter is deprecated.\n"
-                    "Use the parentWindowHandle or currentGLContext parameter instead.");
-
-                if (tokens.size() == 3)
-                {
-                    // Old display:screen:xid format
-                    // The old GLX code always created a "parent" window in this case:
-                    StringConverter::parse(tokens[2], parentWindow);
-                }
-                else if (tokens.size() == 4)
-                {
-                    // Old display:screen:xid:visualinfo format
-                    StringConverter::parse(tokens[2], externalWindow);
-                }
-                else
-                {
-                    // xid format
-                    StringConverter::parse(tokens[0], externalWindow);
-                }
-            }
 
             if ((opt = miscParams->find("border")) != end)
                 border = opt->second;
@@ -254,26 +218,11 @@ namespace Ogre
             if (! XGetWindowAttributes(xDisplay, parentWindow, &windowAttrib) ||
                 windowAttrib.root != DefaultRootWindow(xDisplay))
             {
-                OGRE_EXCEPT(Exception::ERR_RENDERINGAPI_ERROR, "Invalid parentWindowHandle (wrong server or screen)", "GLXWindow::create");
+                OGRE_EXCEPT(Exception::ERR_RENDERINGAPI_ERROR, "Invalid parentWindowHandle (wrong server or screen)");
             }
         }
 
-        // Validate externalWindowHandle
-
-        if (externalWindow != 0)
-        {
-            XWindowAttributes windowAttrib;
-
-            if (! XGetWindowAttributes(xDisplay, externalWindow, &windowAttrib) ||
-                windowAttrib.root != DefaultRootWindow(xDisplay))
-            {
-                OGRE_EXCEPT(Exception::ERR_RENDERINGAPI_ERROR, "Invalid externalWindowHandle (wrong server or screen)", "GLXWindow::create");
-            }
-            glxDrawable = externalWindow;
-        }
-
         // Derive fbConfig
-
         ::GLXFBConfig fbConfig = 0;
 
         if (glxDrawable)
@@ -539,24 +488,6 @@ namespace Ogre
         }
     }
 
-    //-------------------------------------------------------------------------------------------------//
-    bool GLXWindow::isClosed() const
-    {
-        return mClosed;
-    }
-
-    //-------------------------------------------------------------------------------------------------//
-    bool GLXWindow::isVisible() const
-    {
-        return mVisible;
-    }
-
-    //-------------------------------------------------------------------------------------------------//
-    void GLXWindow::setVisible(bool visible)
-    {
-        mVisible = visible;
-    }
-
     //-------------------------------------------------------------------------------------------------//
     void GLXWindow::setHidden(bool hidden)
     {
@@ -580,14 +511,6 @@ namespace Ogre
         }
     }
 
-    //-------------------------------------------------------------------------------------------------//
-    void GLXWindow::setVSyncInterval(unsigned int interval)
-    {
-        mVSyncInterval = interval;
-        if (mVSync)
-            setVSyncEnabled(true);
-    }
-
     //-------------------------------------------------------------------------------------------------//
     void GLXWindow::setVSyncEnabled(bool vsync)
     {
@@ -610,7 +533,7 @@ namespace Ogre
         {
             if( _glXSwapIntervalEXT )
             {
-                _glXSwapIntervalEXT( mGLSupport->getGLDisplay(), mContext->mDrawable,
+                _glXSwapIntervalEXT( mGLSupport->getGLDisplay(), static_cast<GLXContext*>(mContext)->mDrawable,
                                      vsync ? mVSyncInterval : 0 );
             }
             else if( _glXSwapIntervalMESA )
@@ -626,18 +549,6 @@ namespace Ogre
         glXMakeCurrent (mGLSupport->getGLDisplay(), oldDrawable, oldContext);
     }
 
-    //-------------------------------------------------------------------------------------------------//
-    bool GLXWindow::isVSyncEnabled() const
-    {
-        return mVSync;
-    }
-
-    //-------------------------------------------------------------------------------------------------//
-    unsigned int GLXWindow::getVSyncInterval() const
-    {
-        return mVSyncInterval;
-    }
-
     //-------------------------------------------------------------------------------------------------//
     void GLXWindow::reposition(int left, int top)
     {
@@ -700,20 +611,7 @@ namespace Ogre
             XGetWindowAttributes(xDisplay, mWindow, &windowAttrib);
         }
 
-        if (mWidth == (size_t)windowAttrib.width && mHeight == (size_t)windowAttrib.height)
-            return;
-
-        mWidth = windowAttrib.width;
-        mHeight = windowAttrib.height;
-
-        if(!mIsTopLevel)
-        {
-            XResizeWindow(xDisplay, mWindow, mWidth, mHeight);
-            XFlush(xDisplay);
-        }
-
-        for (ViewportList::iterator it = mViewportList.begin(); it != mViewportList.end(); ++it)
-            (*it).second->_updateDimensions();
+        resize(windowAttrib.width, windowAttrib.height);
     }
 
     //-------------------------------------------------------------------------------------------------//
@@ -722,7 +620,7 @@ namespace Ogre
         if (mClosed || mIsExternalGLControl)
             return;
 
-        glXSwapBuffers(mGLSupport->getGLDisplay(), mContext->mDrawable);
+        glXSwapBuffers(mGLSupport->getGLDisplay(), static_cast<GLXContext*>(mContext)->mDrawable);
     }
 
     //-------------------------------------------------------------------------------------------------//
@@ -740,7 +638,7 @@ namespace Ogre
         }
         else if( name == "GLCONTEXT" )
         {
-            *static_cast<GLXContext**>(pData) = mContext;
+            *static_cast<GLContext**>(pData) = mContext;
             return;
         }
         else if( name == "XDISPLAY" )
@@ -766,26 +664,6 @@ namespace Ogre
         return mGLSupport->getContextProfile() == GLNativeSupport::CONTEXT_ES ? PF_BYTE_RGBA : PF_BYTE_RGB;
     }
 
-    void GLXWindow::copyContentsToMemory(const Box& src, const PixelBox &dst, FrameBuffer buffer)
-    {
-        if (mClosed)
-            return;
-
-        if(src.right > mWidth || src.bottom > mHeight || src.front != 0 || src.back != 1
-        || dst.getWidth() != src.getWidth() || dst.getHeight() != src.getHeight() || dst.getDepth() != 1)
-        {
-            OGRE_EXCEPT(Exception::ERR_INVALIDPARAMS, "Invalid box.", "GLXWindow::copyContentsToMemory");
-        }
-
-        if (buffer == FB_AUTO)
-        {
-            buffer = mIsFullScreen? FB_FRONT : FB_BACK;
-        }
-
-        static_cast<GLRenderSystemCommon*>(Root::getSingleton().getRenderSystem())
-                ->_copyContentsToMemory(getViewport(0), src, dst, buffer);
-    }
-
     //-------------------------------------------------------------------------------------------------//
     void GLXWindow::switchFullScreen(bool fullscreen)
     {
@@ -809,6 +687,4 @@ namespace Ogre
             mIsFullScreen = fullscreen;
         }
     }
-
-    GLContext* GLXWindow::getContext() const { return mContext; }
 }
