@@ -69,8 +69,8 @@ namespace Ogre {
     };
 
 
-    CocoaWindow::CocoaWindow() : mWindow(nil), mView(nil), mGLContext(nil), mGLPixelFormat(nil), mWindowOriginPt(NSZeroPoint),
-        mActive(false), mClosed(false), mHidden(false), mVSync(true), mHasResized(false), mIsExternal(false), mWindowTitle(""),
+    CocoaWindow::CocoaWindow() : GLWindow(), mWindow(nil), mView(nil), mGLContext(nil), mGLPixelFormat(nil), mWindowOriginPt(NSZeroPoint),
+        mHasResized(false), mWindowTitle(""),
         mUseOgreGLView(true), mContentScalingFactor(1.0), mStyleMask(NSResizableWindowMask|NSTitledWindowMask)
     {
         // Set vsync by default to save battery and reduce tearing
@@ -198,6 +198,10 @@ namespace Ogre {
             opt = miscParams->find("currentGLContext");
             if (opt != miscParams->end())
                 currentGLContext = StringConverter::parseBool(opt->second);
+
+            opt = miscParams->find("externalGLControl");
+            if (opt != miscParams->end())
+                mIsExternalGLControl = StringConverter::parseBool(opt->second);
             
             opt = miscParams->find("externalGLContext");
             if(opt != miscParams->end())
@@ -247,7 +251,7 @@ namespace Ogre {
             mGLContext = [[NSOpenGLContext currentContext] retain];
             mGLPixelFormat = [mGLContext.pixelFormat retain];
         }
-        else
+        else if(!mIsExternalGLControl)
         {
             NSOpenGLPixelFormatAttribute attribs[30];
             int i = 0;
@@ -306,20 +310,23 @@ namespace Ogre {
             mGLContext = [[NSOpenGLContext alloc] initWithFormat:mGLPixelFormat shareContext:shareContext];
         }
 
-        // Set vsync
-        GLint swapInterval = (GLint)mVSync;
-        [mGLContext setValues:&swapInterval forParameter:NSOpenGLCPSwapInterval];
-        GLint order = (GLint)surfaceOrder;
-        [mGLContext setValues:&order forParameter:NSOpenGLCPSurfaceOrder];
+        if(!mIsExternalGLControl)
+        {
+            // Set vsync
+            GLint swapInterval = (GLint)mVSync;
+            [mGLContext setValues:&swapInterval forParameter:NSOpenGLCPSwapInterval];
+            GLint order = (GLint)surfaceOrder;
+            [mGLContext setValues:&order forParameter:NSOpenGLCPSurfaceOrder];
+        }
         
         // Make active
         setHidden(hidden);
 		mActive = true;
+        mVisible = true;
         mClosed = false;
         mName = [windowTitle cStringUsingEncoding:NSUTF8StringEncoding];
         mWidth = _getPixelFromPoint(widthPt);
         mHeight = _getPixelFromPoint(heightPt);
-        mColourDepth = colourDepth;
         mFSAA = fsaa_samples;
 
         if(!externalWindowHandle)
@@ -444,16 +451,6 @@ namespace Ogre {
         mClosed = true;
     }
 
-    bool CocoaWindow::isActive() const
-    {
-        return mActive;
-    }
-
-    bool CocoaWindow::isClosed() const
-    {
-        return false;
-    }
-
     void CocoaWindow::setHidden(bool hidden)
     {
         mHidden = hidden;
@@ -479,28 +476,6 @@ namespace Ogre {
         if(mGLContext != [NSOpenGLContext currentContext])
             [mGLContext makeCurrentContext];
 	}
-    
-	bool CocoaWindow::isVSyncEnabled() const
-	{
-        return mVSync;
-	}
-
-    void CocoaWindow::copyContentsToMemory(const Box& src, const PixelBox &dst, FrameBuffer buffer)
-    {
-        if(src.right > mWidth || src.bottom > mHeight || src.front != 0 || src.back != 1
-        || dst.getWidth() != src.getWidth() || dst.getHeight() != src.getHeight() || dst.getDepth() != 1)
-        {
-            OGRE_EXCEPT(Exception::ERR_INVALIDPARAMS, "Invalid box.", "CocoaWindow::copyContentsToMemory");
-        }
-        
-        if (buffer == FB_AUTO)
-        {
-            buffer = mIsFullScreen? FB_FRONT : FB_BACK;
-        }
-        
-        static_cast<GLRenderSystemCommon*>(Root::getSingleton().getRenderSystem())
-                ->_copyContentsToMemory(getViewport(0), src, dst, buffer);
-    }
 
     float CocoaWindow::getViewPointToPixelScale()
     {
@@ -584,7 +559,10 @@ namespace Ogre {
         }
         //make sure the context is current
         NSOpenGLContextGuard ctx_guard(mGLContext);
-
+        for (ViewportList::iterator it = mViewportList.begin(); it != mViewportList.end(); ++it)
+        {
+            (*it).second->_updateDimensions();
+        }
 		[mGLContext update];
     }
 
@@ -624,14 +602,17 @@ namespace Ogre {
 
     void CocoaWindow::swapBuffers()
     {
-        CGLLockContext((CGLContextObj)[mGLContext CGLContextObj]);
-        [mGLContext makeCurrentContext];
+        if(!mIsExternalGLControl)
+        {
+            CGLLockContext((CGLContextObj)[mGLContext CGLContextObj]);
+            [mGLContext makeCurrentContext];
 
-        if([mGLContext view] != mView)
-            [mGLContext setView:mView];
+            if([mGLContext view] != mView)
+                [mGLContext setView:mView];
 
-        [mGLContext flushBuffer];
-        CGLUnlockContext((CGLContextObj)[mGLContext CGLContextObj]);
+            [mGLContext flushBuffer];
+            CGLUnlockContext((CGLContextObj)[mGLContext CGLContextObj]);
+        }
     }
 	
 	//-------------------------------------------------------------------------------------------------//
